"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNetworkAndChainName = exports.getNativeChainId = void 0;
const utils_1 = require("../../utils");
const platforms_1 = require("../platforms");
const algorand_1 = require("./algorand");
const aptos_1 = require("./aptos");
const cosmwasm_1 = require("./cosmwasm");
const evm_1 = require("./evm");
const near_1 = require("./near");
const solana_1 = require("./solana");
const sui_1 = require("./sui");
function getNativeChainId(n, c) {
    const platform = (0, platforms_1.chainToPlatform)(c);
    switch (platform) {
        case "Evm":
            return evm_1.evmNetworkChainToEvmChainId.get(n, c).toString();
        case "Cosmwasm":
            return cosmwasm_1.cosmwasmNetworkChainToChainId.get(n, c);
        case "Solana":
            return solana_1.solNetworkChainToGenesisHash.get(n, c);
        case "Sui":
            return sui_1.suiNetworkChainToChainId.get(n, c);
        case "Near":
            return near_1.nearNetworkChainToChainId.get(n, c);
        case "Aptos":
            return aptos_1.aptosNetworkChainToChainId.get(n, c).toString();
        case "Algorand":
            return algorand_1.algorandNetworkChainToChainId.get(n, c);
        case "Btc":
            throw new Error("unmapped");
    }
}
exports.getNativeChainId = getNativeChainId;
function getNetworkAndChainName(platform, chainId) {
    switch (platform) {
        case "Evm":
            // we may get a hex string or a stringified number
            return evm_1.evmChainIdToNetworkChainPair.get(utils_1.encoding.bignum.decode(chainId));
        case "Cosmwasm":
            return cosmwasm_1.cosmwasmChainIdToNetworkChainPair.get(chainId);
        case "Solana":
            return solana_1.solGenesisHashToNetworkChainPair.get(chainId);
        case "Sui":
            return sui_1.suiChainIdToNetworkChain.get(chainId);
        case "Near":
            return near_1.nearChainIdToNetworkChain.get(chainId);
        case "Aptos":
            return aptos_1.aptosChainIdToNetworkChain.get(utils_1.encoding.bignum.decode(chainId));
        case "Algorand":
            return algorand_1.algorandChainIdToNetworkChain.get(chainId);
    }
    throw new Error("Unrecognized platform: " + platform);
}
exports.getNetworkAndChainName = getNetworkAndChainName;
__exportStar(require("./evm"), exports);
__exportStar(require("./solana"), exports);
__exportStar(require("./cosmwasm"), exports);
__exportStar(require("./sui"), exports);
__exportStar(require("./aptos"), exports);
__exportStar(require("./near"), exports);
__exportStar(require("./algorand"), exports);
//# sourceMappingURL=index.js.map