"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fromUint8Array = exports.toUint8Array = exports.bignum = exports.b58 = exports.b64 = exports.hex = exports.stripPrefix = void 0;
const base_1 = require("@scure/base");
const stripPrefix = (prefix, str) => str.startsWith(prefix) ? str.slice(prefix.length) : str;
exports.stripPrefix = stripPrefix;
const isHexRegex = /^(?:0x)?[0-9a-fA-F]+$/;
exports.hex = {
    valid: (input) => isHexRegex.test(input),
    decode: (input) => base_1.base16.decode((0, exports.stripPrefix)("0x", input).toUpperCase()),
    encode: (input, prefix = false) => {
        input = typeof input === "string" ? (0, exports.toUint8Array)(input) : input;
        return (prefix ? "0x" : "") + base_1.base16.encode(input).toLowerCase();
    }
};
// regex string to check if the input could possibly be base64 encoded.
// WARNING: There are clear text strings that are NOT base64 encoded that will pass this check.
const isB64Regex = /^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$/;
exports.b64 = {
    valid: (input) => isB64Regex.test(input),
    decode: base_1.base64.decode,
    encode: (input) => base_1.base64.encode(typeof input === "string" ? (0, exports.toUint8Array)(input) : input)
};
exports.b58 = {
    decode: base_1.base58.decode,
    encode: (input) => base_1.base58.encode(typeof input === "string" ? (0, exports.toUint8Array)(input) : input),
};
exports.bignum = {
    decode: (input) => BigInt(input),
    encode: (input, prefix = false) => (prefix ? "0x" : "") + input.toString(16)
};
const toUint8Array = (value) => typeof value === "bigint"
    ? (0, exports.toUint8Array)(exports.bignum.encode(value))
    : (new TextEncoder()).encode(value);
exports.toUint8Array = toUint8Array;
const fromUint8Array = (value) => (new TextDecoder()).decode(value);
exports.fromUint8Array = fromUint8Array;
//# sourceMappingURL=encoding.js.map